# Generated by Django 3.1.8 on 2021-04-23 11:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_auth", "0022_auto_20210125_2214"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userprofile",
            name="id",
            field=models.AutoField(primary_key=True, serialize=False),
        ),
    ]



class SubjectScheduleError(Exception):
    pass


class NotOnScheduleError(Exception):
    pass


class OnScheduleError(Exception):
    pass


class OffScheduleError(Exception):
    pass


class NotOffScheduleError(Exception):
    pass


class NotOnScheduleForDateError(Exception):
    pass


class OnScheduleForDateError(Exception):
    pass


class OnScheduleFirstAppointmentDateError(Exception):
    pass


class UnknownSubjectError(Exception):
    pass


class InvalidOffscheduleDate(Exception):  # noqa: N818
    pass


class ScheduleError(Exception):
    pass


class ScheduledVisitWindowError(Exception):
    pass


class UnScheduledVisitWindowError(Exception):
    pass


class SiteVisitScheduleError(Exception):
    pass


class RegistryNotLoaded(Exception):  # noqa: N818
    pass


class AlreadyRegisteredVisitSchedule(Exception):  # noqa: N818
    pass


class VisitScheduleBaselineError(Exception):
    pass


class VisitScheduleNonCrfModelFormMixinError(Exception):
    pass



# Generated by Django 4.2.1 on 2023-07-07 19:32

from django.db import migrations

import edc_identifier.managers
import edc_sites.models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_offstudy", "0017_alter_subjectoffstudy_options"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectoffstudy",
            managers=[
                ("objects", edc_identifier.managers.SubjectIdentifierManager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]



# Generated by Django 3.0.9 on 2020-10-02 01:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("edc_export", "0007_auto_20200512_0452"),
    ]

    operations = [
        migrations.AlterField(
            model_name="datarequest",
            name="export_format",
            field=models.CharField(
                choices=[
                    ("CSV", "CSV (delimited by pipe `|`"),
                    (114, "Stata v10 or later"),
                    (117, "Stata v13 or later"),
                    (118, "Stata v14 or later"),
                    (119, "Stata v15 or later"),
                ],
                default="CSV",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="historicaldatarequest",
            name="export_format",
            field=models.CharField(
                choices=[
                    ("CSV", "CSV (delimited by pipe `|`"),
                    (114, "Stata v10 or later"),
                    (117, "Stata v13 or later"),
                    (118, "Stata v14 or later"),
                    (119, "Stata v15 or later"),
                ],
                default="CSV",
                max_length=25,
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-17 16:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_refusal", "0011_alter_historicalsubjectrefusal_revision_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="comment",
            field=models.TextField(
                blank=True, default="", verbose_name="Additional Comments"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="refusalreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="refusalreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="refusalreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="comment",
            field=models.TextField(
                blank=True, default="", verbose_name="Additional Comments"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrefusal",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
    ]
